@@ -444,7 +444,7 @@ def generate_word_document(
     # Extract payload values
     header = payload.get("header", "Default Title")
     paragraph = payload.get("paragraph", "Default paragraph content.")
-    save_pdf = payload.get("save_pdf", True)
+    save_docx = payload.get("save_docx", True)
     send_email = payload.get("send_email", True)
     to_email = payload.get("to_email", "eagle0504@gmail.com")
 
@@ -452,12 +452,12 @@ def generate_word_document(
     email_key = secrets.get("email_key")
 
     # Log the API call details
-    print(f"Generating Word document with header: {header}, save_pdf: {save_pdf}")
+    print(f"Generating Word document with header: {header}, save_docx: {save_docx}")
 
     response = {}
 
     try:
-        if save_pdf:
+        if save_docx:
             # Create a Word document
             document = Document()
             document.add_heading(header, level=1)
@@ -499,15 +499,22 @@ def generate_word_document(
 
                 # Send the email
                 try:
-                    with smtplib.SMTP_SSL("smtp.gmail.com", 465) as server:  # SMTP server for Gmail
+                    with smtplib.SMTP_SSL(
+                        "smtp.gmail.com", 465
+                    ) as server:  # SMTP server for Gmail
                         server.login(from_email, password)
                         server.send_message(msg)
-                    print(f"Email sent successfully to {to_email} with the attached document: {file_name}")
+                    print(
+                        f"Email sent successfully to {to_email} with the attached document: {file_name}"
+                    )
                 except Exception as e:
                     print(f"Failed to send email: {str(e)}")
 
         else:
-            response = {"status": "skipped", "message": "Saving the Word document is disabled."}
+            response = {
+                "status": "skipped",
+                "message": "Saving the Word document is disabled.",
+            }
 
     except Exception as e:
         response = {
